@@ -166,9 +166,11 @@ class Interpreter():
         """Initialize the interpreter"""
         pass
 
-    def interpret(self, code: str, variables_dict: dict = {}, function_dict: dict = {}, debug_mode: bool = False,library: bool = False) -> str:
+    def interpret(self, code: str, variables_dict: dict = None, function_dict: dict = None, debug_mode: bool = False,library: bool = False) -> str:
         """Interprets the code"""
         code = code.split(" ")
+        variables_dict = {} if variables_dict is None else variables_dict
+        function_dict = {} if function_dict is None else function_dict
         variables = variables_dict
         functions = function_dict
         for j in range(0, len(code)):
